@@ -4,29 +4,22 @@ use strict 'subs', 'vars';
 use Regexp::Pattern::Perl::Module ();
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-06-13'; # DATE
+our $DATE = '2024-01-24'; # DATE
 our $DIST = 'Module-Load-Util'; # DIST
-our $VERSION = '0.009'; # VERSION
+our $VERSION = '0.010'; # VERSION
 
 use Exporter 'import';
 our @EXPORT_OK = qw(
                        load_module_with_optional_args
                        instantiate_class_with_optional_args
+                       call_module_function_with_optional_args
+                       call_module_method_with_optional_args
                );
 
-sub load_module_with_optional_args {
-    my $opts = ref($_[0]) eq 'HASH' ? shift : {};
+sub _normalize_module_with_optional_args {
     my $module_with_optional_args = shift;
 
-    my $target_package =
-        defined $opts->{target_package} ? $opts->{target_package} :
-        defined $opts->{caller} ? $opts->{caller} :
-        caller(0);
-    # check because we will use eval ""
-    $target_package =~ $Regexp::Pattern::Perl::Module::RE{perl_modname}{pat}
-        or die "Invalid syntax in target package '$target_package'";
-
-    my ($module, $args) = @_;
+    my ($module, $args);
     if (ref $module_with_optional_args eq 'ARRAY') {
         die "array form or module/class name must have 1 or 2 elements"
             unless @$module_with_optional_args == 1 || @$module_with_optional_args == 2;
@@ -38,13 +31,22 @@ sub load_module_with_optional_args {
     } elsif (ref $module_with_optional_args) {
         die "module/class name must be string or 2-element array, not ".
             $module_with_optional_args;
-    } elsif ($module_with_optional_args =~ /(.+?)=(.*)/) {
+    } elsif ($module_with_optional_args =~ /(.+?)[=,](.*)/) {
         $module = $1;
         $args = [split /,/, $2];
     } else {
         $module = $module_with_optional_args;
         $args = [];
     }
+    ($module, $args);
+}
+
+sub _load_module {
+    my $opts = ref $_[0] eq 'HASH' ? shift : {};
+    my $module = shift;
+
+    my $do_load = defined $opts->{load} ? $opts->{load} : 1;
+    return $module unless $do_load;
 
     my @ns_prefixes = $opts->{ns_prefixes} ? @{$opts->{ns_prefixes}} :
         defined($opts->{ns_prefix}) ? ($opts->{ns_prefix}) : ('');
@@ -59,20 +61,35 @@ sub load_module_with_optional_args {
             $module_with_prefix = $module;
         }
 
-        if ($opts->{load} // 1) {
-            (my $module_with_prefix_pm = "$module_with_prefix.pm") =~ s!::!/!g;
-            if ($try_all) {
-                eval { require $module_with_prefix_pm }; last unless $@;
-                warn $@ if $@ !~ /\ACan't locate/;
-            } else {
-                require $module_with_prefix_pm;
-            }
+        (my $module_with_prefix_pm = "$module_with_prefix.pm") =~ s!::!/!g;
+        if ($try_all) {
+            eval { require $module_with_prefix_pm }; last unless $@;
+            warn $@ if $@ !~ /\ACan't locate/;
+        } else {
+            require $module_with_prefix_pm;
         }
     }
     if ($@) {
         die "load_module_with_optional_args(): Failed to load module '$module' (all prefixes tried: ".join(", ", @ns_prefixes).")";
     }
-    $module = $module_with_prefix;
+    $module_with_prefix;
+}
+
+sub load_module_with_optional_args {
+    my $opts = ref($_[0]) eq 'HASH' ? shift : {};
+    my $module_with_optional_args = shift;
+
+    my $target_package =
+        defined $opts->{target_package} ? $opts->{target_package} :
+        defined $opts->{caller} ? $opts->{caller} :
+        caller(0);
+    # check because we will use eval ""
+    $target_package =~ $Regexp::Pattern::Perl::Module::RE{perl_modname}{pat}
+        or die "Invalid syntax in target package '$target_package'";
+
+    my ($module, $args) = _normalize_module_with_optional_args(
+        $module_with_optional_args);
+    $module = _load_module($opts, $module);
 
     my $do_import = defined $opts->{import} ? $opts->{import} : 1;
     if ($do_import) {
@@ -104,6 +121,34 @@ sub instantiate_class_with_optional_args {
     }
 }
 
+sub call_module_function_with_optional_args {
+    my $opts = ref($_[0]) eq 'HASH' ? shift : {};
+    my $module_with_optional_args = shift;
+
+    my ($module, $args) = _normalize_module_with_optional_args(
+        $module_with_optional_args);
+    $module =~ s/\A(.+)::(\w+)\z/$1/ or die "Please specify MODULE::FUNCTION, not just module name '$module'";
+    my $func = $2;
+
+    _load_module($opts, $module);
+
+    &{"$module\::$func"}(@$args);
+}
+
+sub call_module_method_with_optional_args {
+    my $opts = ref($_[0]) eq 'HASH' ? shift : {};
+    my $module_with_optional_args = shift;
+
+    my ($module, $args) = _normalize_module_with_optional_args(
+        $module_with_optional_args);
+    $module =~ s/\A(.+)::(\w+)\z/$1/ or die "Please specify MODULE::FUNCTION, not just module name '$module'";
+    my $func = $2;
+
+    _load_module($opts, $module);
+
+    $module->$func(@$args);
+}
+
 1;
 # ABSTRACT: Some utility routines related to module loading
 
@@ -119,13 +164,15 @@ Module::Load::Util - Some utility routines related to module loading
 
 =head1 VERSION
 
-This document describes version 0.009 of Module::Load::Util (from Perl distribution Module-Load-Util), released on 2023-06-13.
+This document describes version 0.010 of Module::Load::Util (from Perl distribution Module-Load-Util), released on 2024-01-24.
 
 =head1 SYNOPSIS
 
  use Module::Load::Util qw(
      load_module_with_optional_args
      instantiate_class_with_optional_args
+     call_module_function_with_optional_args
+     call_module_method_with_optional_args
  );
 
  load_module_with_optional_args("Foo::Bar=import-arg1,import-arg2");
@@ -273,6 +320,41 @@ not want to C<require()>, e.g. when the class is already defined somewhere else.
 
 =back
 
+=head2 call_module_function_with_optional_args
+
+Usage:
+
+ call_module_function_with_optional_args( [ \%opts , ] $function_with_optional_args );
+
+Examples:
+
+ call_module_function_with_optional_args("App::ChromeUtils::chrome_is_running");
+ call_module_function_with_optional_args("App::ChromeUtils::start_chrome=quiet,1");
+ call_module_function_with_optional_args("Color::RGB::Util::int2rgb=100500");
+ call_module_function_with_optional_args(["App::ChromeUtils::start_chrome" => {quiet=>1}]);
+ call_module_function_with_optional_args(["Color::RGB::Util::int2rgb" => [100500]]);
+
+ call_module_function_with_optional_args({load=>0}, ["Color::RGB::Util::int2rgb" => [100500]]);
+
+Load module then call module's function with optional arguments.
+
+Known options:
+
+=over
+
+=item * load
+
+=item * ns_prefix
+
+=item * ns_prefixes
+
+=back
+
+=head2 call_module_method_with_optional_args
+
+Just like L</call_module_function_with_optional_args> except the subroutine call
+is replaced with a method call instead.
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Module-Load-Util>.
@@ -313,7 +395,7 @@ that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2023, 2022, 2021, 2020 by perlancar <perlancar@cpan.org>.
+This software is copyright (c) 2024, 2023, 2022, 2021, 2020 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
